@@ -3,6 +3,7 @@
 
 class AttId:
     att = 'att'
+    centerxy = 'centerxy'
     datapointeid = 'datapointeid'
     datapointseids = 'datapointseids'
     datatypeeid = 'datatypeeid'
@@ -76,3 +77,6 @@ class NetworkObjId:
 
 INDICATORS_DATA_TYPES = (DataTypeId.karrusrd, DataTypeId.metropme, DataTypeId.tomtomfcd, DataTypeId.roads,
                          DataTypeId.zones)
+
+MISSING_VALUE = -1
+NO_VALUE = ''
